Changelog
=========


v0.1.0 (8th April 2024)
------------------------

- Add goresym support in go-inspector.



v0.2.0 (9th April 2024)
------------------------

- Add missing ABOUT file and license for goresym.
- Bump to version GoReSym 2.7.2
- Add support for dependencies and build info
